==> rook_users-0.4.1.tar.gz: test/src/authorization/get_expiration_date_from_json_web_token_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:rook_users/src/authorization/get_expiration_date_from_json_web_token.dart';

void main() {
  group('getExpirationDateFromJsonWebToken', () {
    test('GIVEN a valid exp WHEN getExpirationDateFromJsonWebToken THEN return the expected result', () {
      final millis = DateTime.timestamp().add(const Duration(days: 30)).millisecondsSinceEpoch;
      final exp = (millis / 1000).round();

      final jsonWebToken = {
        'iat': exp,
        'exp': exp,
        'enabled_features': {
          'users': 1,
        },
      };

      final result = getExpirationDateFromJsonWebToken(jsonWebToken);

      expect((result.millisecondsSinceEpoch / 1000.0).round(), exp);
    });

    test('GIVEN an enabled JsonWebToken WHEN getExpirationDateFromJsonWebToken THEN return a valid expiration date', () {
      final millis = DateTime.timestamp().add(const Duration(days: 30)).millisecondsSinceEpoch;
      final exp = (millis / 1000).round();

      final jsonWebToken = {
        'iat': exp,
        'exp': exp,
        'enabled_features': {
          'users': 1,
        },
      };

      final result = getExpirationDateFromJsonWebToken(jsonWebToken);
      final now = DateTime.timestamp();

      expect(now.isBefore(result), true);
    });

    test('GIVEN a disabled JsonWebToken WHEN getExpirationDateFromJsonWebToken THEN return an invalid expiration date', () {
      final millis = DateTime.timestamp().add(const Duration(days: 30)).millisecondsSinceEpoch;
      final exp = (millis / 1000).round();

      final jsonWebToken = {
        'iat': exp,
        'exp': exp,
        'enabled_features': {
          'users': 0,
        },
      };

      final result = getExpirationDateFromJsonWebToken(jsonWebToken);
      final now = DateTime.timestamp();

      expect(now.isBefore(result), false);
    });
  });
}

==> rook_users-0.5.1.tar.gz: test/src/authorization/get_expiration_date_from_json_web_token_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:rook_users/src/authorization/get_expiration_date_from_json_web_token.dart';

void main() {
  group('getExpirationDateFromJsonWebToken', () {
    test(
        'GIVEN a valid exp WHEN getExpirationDateFromJsonWebToken THEN return the expected result',
        () {
      final millis = DateTime.timestamp()
          .add(const Duration(days: 30))
          .millisecondsSinceEpoch;
      final exp = (millis / 1000).round();

      final jsonWebToken = {
        'iat': exp,
        'exp': exp,
        'enabled_features': {
          'users': 1,
        },
      };

      final result = getExpirationDateFromJsonWebToken(jsonWebToken);

      expect((result.millisecondsSinceEpoch / 1000.0).round(), exp);
    });

    test(
        'GIVEN an enabled JsonWebToken WHEN getExpirationDateFromJsonWebToken THEN return a valid expiration date',
        () {
      final millis = DateTime.timestamp()
          .add(const Duration(days: 30))
          .millisecondsSinceEpoch;
      final exp = (millis / 1000).round();

      final jsonWebToken = {
        'iat': exp,
        'exp': exp,
        'enabled_features': {
          'users': 1,
        },
      };

      final result = getExpirationDateFromJsonWebToken(jsonWebToken);
      final now = DateTime.timestamp();

      expect(now.isBefore(result), true);
    });

    test(
        'GIVEN a disabled JsonWebToken WHEN getExpirationDateFromJsonWebToken THEN return an invalid expiration date',
        () {
      final millis = DateTime.timestamp()
          .add(const Duration(days: 30))
          .millisecondsSinceEpoch;
      final exp = (millis / 1000).round();

      final jsonWebToken = {
        'iat': exp,
        'exp': exp,
        'enabled_features': {
          'users': 0,
        },
      };

      final result = getExpirationDateFromJsonWebToken(jsonWebToken);
      final now = DateTime.timestamp();

      expect(now.isBefore(result), false);
    });
  });
}
